## Summary

<!-- Brief description of the changes. What problem does this solve? -->

## Changes

<!-- Bulleted list of specific changes made -->

-

## Type of change

<!-- Check the relevant option -->

- [ ] Bug fix (`fix`)
- [ ] New feature (`feat`)
- [ ] Breaking change (`feat!` / `fix!`)
- [ ] Documentation (`docs`)
- [ ] Refactoring (`refactor`)
- [ ] Test coverage (`test`)
- [ ] CI/CD (`ci`)
- [ ] Other: <!-- specify -->

## Checklist

- [ ] PR title follows [conventional commit](https://www.conventionalcommits.org/) format
- [ ] `uv run ruff check .` passes
- [ ] `uv run ruff format --check .` passes
- [ ] `uv run pytest` passes
- [ ] `uv run mypy src/` passes
- [ ] New/changed behavior includes tests
- [ ] Documentation updated if applicable

## Test plan

<!-- How was this tested? Include commands or screenshots if helpful. -->
